@@ -5,7 +5,7 @@
 
 fn main() {
     println!("cargo:rerun-if-changed=build.rs");
-    if cfg!(feature = "blas-openblas-sys") {
+    if cfg!(feature = "test-blas-openblas-sys") {
         println!("cargo:rustc-link-lib={}=openblas", "dylib");
     }
 }
