@@ -28,26 +28,10 @@ use {Zip, FoldWhile};
 
 #[cold]
 #[inline(never)]
-fn array_out_of_bounds() -> ! {
+pub(crate) fn array_out_of_bounds() -> ! {
     panic!("ndarray: index out of bounds");
 }
 
-// Macro to insert more informative out of bounds message in debug builds
-#[cfg(debug_assertions)]
-macro_rules! debug_bounds_check {
-    ($self_:ident, $index:expr) => {
-        if let None = $index.index_checked(&$self_.dim, &$self_.strides) {
-            panic!("ndarray: index {:?} is out of bounds for array of shape {:?}",
-                   $index, $self_.shape());
-        }
-    };
-}
-
-#[cfg(not(debug_assertions))]
-macro_rules! debug_bounds_check {
-    ($self_:ident, $index:expr) => { };
-}
-
 #[inline(always)]
 pub fn debug_bounds_check<S, D, I>(_a: &ArrayBase<S, D>, _index: &I)
     where D: Dimension,
