@@ -9,7 +9,7 @@
 //! The data (inner representation) traits for ndarray
 
 use std::mem::{self, size_of};
-use std::rc::Rc;
+use std::sync::Arc;
 
 use {
     ArrayBase,
@@ -17,6 +17,7 @@ use {
     ViewRepr,
     OwnedRepr,
     OwnedRcRepr,
+    OwnedArcRepr,
 };
 
 /// Array representation trait.
@@ -71,7 +72,7 @@ pub unsafe trait DataClone : Data {
     }
 }
 
-unsafe impl<A> Data for OwnedRcRepr<A> {
+unsafe impl<A> Data for OwnedArcRepr<A> {
     type Elem = A;
     fn _data_slice(&self) -> &[A] {
         &self.0
@@ -80,14 +81,14 @@ unsafe impl<A> Data for OwnedRcRepr<A> {
 }
 
 // NOTE: Copy on write
-unsafe impl<A> DataMut for OwnedRcRepr<A>
+unsafe impl<A> DataMut for OwnedArcRepr<A>
     where A: Clone
 {
     fn ensure_unique<D>(self_: &mut ArrayBase<Self, D>)
         where Self: Sized,
               D: Dimension
     {
-        if Rc::get_mut(&mut self_.data.0).is_some() {
+        if Arc::get_mut(&mut self_.data.0).is_some() {
             return;
         }
         if self_.dim.size() <= self_.data.0.len() / 2 {
@@ -106,18 +107,18 @@ unsafe impl<A> DataMut for OwnedRcRepr<A>
         let our_off = if a_size != 0 {
             (self_.ptr as isize - rcvec.as_ptr() as isize) / a_size
         } else { 0 };
-        let rvec = Rc::make_mut(rcvec);
+        let rvec = Arc::make_mut(rcvec);
         unsafe {
             self_.ptr = rvec.as_mut_ptr().offset(our_off);
         }
     }
 
     fn is_unique(&mut self) -> bool {
-        Rc::get_mut(&mut self.0).is_some()
+        Arc::get_mut(&mut self.0).is_some()
     }
 }
 
-unsafe impl<A> DataClone for OwnedRcRepr<A> {
+unsafe impl<A> DataClone for OwnedArcRepr<A> {
     unsafe fn clone_with_ptr(&self, ptr: *mut Self::Elem) -> (Self, *mut Self::Elem) {
         // pointer is preserved
         (self.clone(), ptr)
@@ -216,7 +217,7 @@ unsafe impl<A> DataOwned for OwnedRepr<A> {
         OwnedRepr(elements)
     }
     fn into_shared(self) -> OwnedRcRepr<A> {
-        OwnedRcRepr(Rc::new(self.0))
+        OwnedArcRepr(Arc::new(self.0))
     }
     #[inline]
     fn into_owned<D>(self_: ArrayBase<Self, D>) -> ArrayBase<OwnedRepr<Self::Elem>, D>
@@ -228,20 +229,22 @@ unsafe impl<A> DataOwned for OwnedRepr<A> {
     }
 }
 
-unsafe impl<A> DataOwned for OwnedRcRepr<A> {
+unsafe impl<A> DataOwned for OwnedArcRepr<A> {
     fn new(elements: Vec<A>) -> Self {
-        OwnedRcRepr(Rc::new(elements))
+        OwnedArcRepr(Arc::new(elements))
     }
+
     fn into_shared(self) -> OwnedRcRepr<A> {
         self
     }
+
     fn into_owned<D>(mut self_: ArrayBase<Self, D>) -> ArrayBase<OwnedRepr<Self::Elem>, D>
     where
         A: Clone,
         D: Dimension,
     {
         Self::ensure_unique(&mut self_);
-        let data = OwnedRepr(Rc::try_unwrap(self_.data.0).ok().unwrap());
+        let data = OwnedRepr(Arc::try_unwrap(self_.data.0).ok().unwrap());
         ArrayBase {
             data: data,
             ptr: self_.ptr,
