@@ -74,6 +74,15 @@
 //!     Uses ``blas-src`` for pluggable backend, which needs to be configured
 //!     separately.
 //!
+//! ## Documentation
+//!
+//! * The docs for [`ArrayBase`](struct.ArrayBase.html) provide an overview of
+//!   the *n*-dimensional array type. Other good pages to look at are the
+//!   documentation for the [`s![]`](macro.s.html) and
+//!   [`azip!()`](macro.azip.html) macros.
+//!
+//! * If you have experience with NumPy, you may also be interested in
+//!   [`ndarray_for_numpy_users`](doc/ndarray_for_numpy_users/index.html).
 
 #[cfg(feature = "serde-1")]
 extern crate serde;
@@ -91,8 +100,11 @@ extern crate matrixmultiply;
 extern crate num_traits as libnum;
 extern crate num_complex;
 
+#[cfg(feature = "docs")]
+pub mod doc;
+
 use std::marker::PhantomData;
-use std::rc::Rc;
+use std::sync::Arc;
 
 pub use dimension::{
     Dimension,
@@ -202,18 +214,18 @@ pub type Ixs = isize;
 /// The `ArrayBase<S, D>` is parameterized by `S` for the data container and
 /// `D` for the dimensionality.
 ///
-/// Type aliases [`Array`], [`RcArray`], [`ArrayView`], and [`ArrayViewMut`] refer
+/// Type aliases [`Array`], [`ArcArray`], [`ArrayView`], and [`ArrayViewMut`] refer
 /// to `ArrayBase` with different types for the data container.
 ///
 /// [`Array`]: type.Array.html
-/// [`RcArray`]: type.RcArray.html
+/// [`ArcArray`]: type.ArcArray.html
 /// [`ArrayView`]: type.ArrayView.html
 /// [`ArrayViewMut`]: type.ArrayViewMut.html
 ///
 /// ## Contents
 ///
 /// + [Array](#array)
-/// + [RcArray](#rcarray)
+/// + [ArcArray](#arcarray)
 /// + [Array Views](#array-views)
 /// + [Indexing and Dimension](#indexing-and-dimension)
 /// + [Loops, Producers and Iterators](#loops-producers-and-iterators)
@@ -244,12 +256,12 @@ pub type Ixs = isize;
 /// temperature[[2, 2, 2]] += 0.5;
 /// ```
 ///
-/// ## `RcArray`
+/// ## `ArcArray`
 ///
-/// [`RcArray`](type.RcArray.html) is an owned array with reference counted
+/// [`ArcArray`](type.ArcArray.html) is an owned array with reference counted
 /// data (shared ownership).
 /// Sharing requires that it uses copy-on-write for mutable operations.
-/// Calling a method for mutating elements on `RcArray`, for example
+/// Calling a method for mutating elements on `ArcArray`, for example
 /// [`view_mut()`](#method.view_mut) or [`get_mut()`](#method.get_mut),
 /// will break sharing and require a clone of the data (if it is not uniquely held).
 ///
@@ -572,8 +584,8 @@ pub type Ixs = isize;
 /// ### Binary Operators with Two Arrays
 ///
 /// Let `A` be an array or view of any kind. Let `B` be an array
-/// with owned storage (either `Array` or `RcArray`).
-/// Let `C` be an array with mutable data (either `Array`, `RcArray`
+/// with owned storage (either `Array` or `ArcArray`).
+/// Let `C` be an array with mutable data (either `Array`, `ArcArray`
 /// or `ArrayViewMut`).
 /// The following combinations of operands
 /// are supported for an arbitrary binary operator denoted by `@` (it can be
@@ -598,7 +610,7 @@ pub type Ixs = isize;
 /// ### Unary Operators
 ///
 /// Let `A` be an array or view of any kind. Let `B` be an array with owned
-/// storage (either `Array` or `RcArray`). The following operands are supported
+/// storage (either `Array` or `ArcArray`). The following operands are supported
 /// for an arbitrary unary operator denoted by `@` (it can be `-` or `!`).
 ///
 /// - `@&A` which produces a new `Array`
@@ -648,11 +660,27 @@ pub struct ArrayBase<S, D>
 }
 
 /// An array where the data has shared ownership and is copy on write.
+///
+/// It can act as both an owner as the data as well as a shared reference (view like).
+///
+/// **Note: this type alias is obsolete.** See the equivalent [`ArcArray`] instead.
+// Use soon: #[deprecated(note="RcArray is replaced by ArcArray")]
+pub type RcArray<A, D> = ArrayBase<OwnedRcRepr<A>, D>;
+
+/// An array where the data has shared ownership and is copy on write.
+///
+/// The `ArcArray<A, D>` is parameterized by `A` for the element type and `D` for
+/// the dimensionality.
+///
 /// It can act as both an owner as the data as well as a shared reference (view
 /// like).
+/// Calling a method for mutating elements on `ArcArray`, for example
+/// [`view_mut()`](struct.ArrayBase.html#method.view_mut) or
+/// [`get_mut()`](struct.ArrayBase.html#method.get_mut), will break sharing and
+/// require a clone of the data (if it is not uniquely held).
 ///
-/// The `RcArray<A, D>` is parameterized by `A` for the element type and `D` for
-/// the dimensionality.
+/// `ArcArray` uses atomic reference counting like `Arc`, so it is `Send` and
+/// `Sync` (when allowed by the element type of the array too).
 ///
 /// [**`ArrayBase`**](struct.ArrayBase.html) is used to implement both the owned
 /// arrays and the views; see its docs for an overview of all array features.  
@@ -661,7 +689,7 @@ pub struct ArrayBase<S, D>
 ///
 /// + [Constructor Methods for Owned Arrays](struct.ArrayBase.html#constructor-methods-for-owned-arrays)
 /// + [Methods For All Array Types](struct.ArrayBase.html#methods-for-all-array-types)
-pub type RcArray<A, D> = ArrayBase<OwnedRcRepr<A>, D>;
+pub type ArcArray<A, D> = ArrayBase<OwnedArcRepr<A>, D>;
 
 /// An array that owns its data uniquely.
 ///
@@ -727,16 +755,23 @@ pub struct OwnedRepr<A>(Vec<A>);
 ///
 /// *Don’t use this type directly—use the type alias
 /// [`RcArray`](type.RcArray.html) for the array type!*
+#[deprecated(note="RcArray is replaced by ArcArray")]
+pub use self::OwnedArcRepr as OwnedRcRepr;
+
+/// ArcArray's representation.
+///
+/// *Don’t use this type directly—use the type alias
+/// [`ArcArray`](type.ArcArray.html) for the array type!*
 #[derive(Debug)]
-pub struct OwnedRcRepr<A>(Rc<Vec<A>>);
+pub struct OwnedArcRepr<A>(Arc<Vec<A>>);
 
-
-impl<A> Clone for OwnedRcRepr<A> {
+impl<A> Clone for OwnedArcRepr<A> {
     fn clone(&self) -> Self {
-        OwnedRcRepr(self.0.clone())
+        OwnedArcRepr(self.0.clone())
     }
 }
 
+
 /// Array view’s representation.
 ///
 /// *Don’t use this type directly—use the type aliases
